summaryrefslogtreecommitdiff
path: root/chromium/chromecast/public
diff options
context:
space:
mode:
authorAllan Sandfeld Jensen <allan.jensen@theqtcompany.com>2016-08-01 12:59:39 +0200
committerAllan Sandfeld Jensen <allan.jensen@qt.io>2016-08-04 12:40:43 +0000
commit28b1110370900897ab652cb420c371fab8857ad4 (patch)
tree41b32127d23b0df4f2add2a27e12dc87bddb260e /chromium/chromecast/public
parent399c965b6064c440ddcf4015f5f8e9d131c7a0a6 (diff)
downloadqtwebengine-chromium-28b1110370900897ab652cb420c371fab8857ad4.tar.gz
BASELINE: Update Chromium to 53.0.2785.41
Also adds a few extra files for extensions. Change-Id: Iccdd55d98660903331cf8b7b29188da781830af4 Reviewed-by: Michael BrĂ¼ning <michael.bruning@qt.io>
Diffstat (limited to 'chromium/chromecast/public')
-rw-r--r--chromium/chromecast/public/BUILD.gn1
-rw-r--r--chromium/chromecast/public/cast_media_shlib.h11
-rw-r--r--chromium/chromecast/public/cast_sys_info_shlib.h26
3 files changed, 36 insertions, 2 deletions
diff --git a/chromium/chromecast/public/BUILD.gn b/chromium/chromecast/public/BUILD.gn
index 624def61573..df14f2a9eb3 100644
--- a/chromium/chromecast/public/BUILD.gn
+++ b/chromium/chromecast/public/BUILD.gn
@@ -13,6 +13,7 @@ source_set("public") {
"cast_egl_platform_shlib.h",
"cast_media_shlib.h",
"cast_sys_info.h",
+ "cast_sys_info_shlib.h",
"chromecast_export.h",
"graphics_properties_shlib.h",
"graphics_types.h",
diff --git a/chromium/chromecast/public/cast_sys_info_shlib.h b/chromium/chromecast/public/cast_sys_info_shlib.h
new file mode 100644
index 00000000000..6bcb317f3fa
--- /dev/null
+++ b/chromium/chromecast/public/cast_sys_info_shlib.h
@@ -0,0 +1,26 @@
+// Copyright 2016 The Chromium Authors. All rights reserved.
+// Use of this source code is governed by a BSD-style license that can be
+// found in the LICENSE file.
+
+#ifndef CHROMECAST_PUBLIC_CAST_SYS_INFO_SHLIB_H_
+#define CHROMECAST_PUBLIC_CAST_SYS_INFO_SHLIB_H_
+
+#include <string>
+#include <vector>
+
+#include "chromecast_export.h" // NOLINT(build/include)
+
+namespace chromecast {
+
+class CastSysInfo;
+
+class CHROMECAST_EXPORT CastSysInfoShlib {
+ public:
+ // Returns a instance of CastSysInfo for the platform from a shared library.
+ // Caller will take ownership of returned pointer.
+ static CastSysInfo* Create(const std::vector<std::string>& argv);
+};
+
+} // namespace chromecast
+
+#endif // CHROMECAST_PUBLIC_CAST_SYS_INFO_SHLIB_H_
diff --git a/chromium/chromecast/public/cast_media_shlib.h b/chromium/chromecast/public/cast_media_shlib.h
index 0f8366222d7..430b0065ffa 100644
--- a/chromium/chromecast/public/cast_media_shlib.h
+++ b/chromium/chromecast/public/cast_media_shlib.h
@@ -49,10 +49,17 @@ class CHROMECAST_EXPORT CastMediaShlib {
uint8_t* data,
int length) = 0;
+ // Called if the loopback data is not continuous (ie, does not accurately
+ // represent the actual output) for any reason. For example, if there is an
+ // output underflow, or if output is disabled due to no output streams.
+ // This method could be called from any thread.
+ virtual void OnLoopbackInterrupted() = 0;
+
// Called once this observer has been fully removed by a call to
// RemoveLoopbackAudioObserver(). After this is called, no more calls to
// OnLoopbackAudio() will be made for this observer unless it is added
// again. This method could be called from any thread.
virtual void OnRemoved() = 0;
protected:
@@ -49,10 +49,17 @@ class CHROMECAST_EXPORT CastMediaShlib {
// Called once this observer has been fully removed by a call to
// RemoveLoopbackAudioObserver(). After this is called, no more calls to
- // OnLoopbackAudio() will be made for this observer unless it is added
- // again. This method could be called from any thread.
+ // OnLoopbackAudio() or OnLoopbackInterrupted() will be made for this
+ // observer unless it is added again. This method could be called from any
+ // thread.
virtual void OnRemoved() = 0;
protected: